@@ -17,7 +17,9 @@ async def resolve_handler(
     result: ResolvedItem,
     is_auto_resolve: IsAutoResolve,
 ):
-    result_it: Any = cast(Any, result)  # fuck that annoying weak type annotation
+    if not result:
+        await matcher.finish("未能从您的消息中解析到有效信息")
+    result_it: Any = cast("Any", result)  # fuck that annoying weak type annotation
     if is_auto_resolve and isinstance(result, BaseSongList):
         await (await construct_info_msg(result_it, tip_command=True)).send()
     else:
@@ -28,7 +30,7 @@ async def resolve_handler(
 def __register_resolve_matchers():
     matcher = on_command("解析", aliases={"resolve", "parse", "get"})
     matcher.handle()(resolve_handler)
-    if config.ncm_auto_resolve:
+    if config.auto_resolve:
         reg_matcher = on_regex(URL_REGEX)
         reg_matcher.handle()(resolve_handler)
         reg_short_matcher = on_regex(SHORT_URL_REGEX)
