@@ -1,4 +1,6 @@
 from .base import (
+    FILESYSTEM_CHAR_REPLACEMENTS as FILESYSTEM_CHAR_REPLACEMENTS,
+    FILESYSTEM_DISALLOWED_CHARS as FILESYSTEM_DISALLOWED_CHARS,
     build_item_link as build_item_link,
     calc_max_page as calc_max_page,
     calc_min_index as calc_min_index,
@@ -12,11 +14,16 @@ from .base import (
     format_artists as format_artists,
     format_time as format_time,
     get_thumb_url as get_thumb_url,
+    half_to_full as half_to_full,
     is_song_card_supported as is_song_card_supported,
     merge_alias as merge_alias,
 )
 from .lrc_parser import (
+    NCM_MAIN_LRC_GROUP as NCM_MAIN_LRC_GROUP,
+    LrcGroupLine as LrcGroupLine,
     LrcLine as LrcLine,
+    NCMLrcGroupLine as NCMLrcGroupLine,
+    NCMLrcGroupNameType as NCMLrcGroupNameType,
     merge_lrc as merge_lrc,
     normalize_lrc as normalize_lrc,
     parse_lrc as parse_lrc,
